Utils
=====

Very general purpose helper functions and logic that can be utilized by other packages in our ecosystem.

.. automodule:: nwbinspector
    :members:
    :no-undoc-members:
    :noindex:

.. toctree::
    :maxdepth: 4

.. automodule:: nwbinspector.utils
    :noindex:
